@@ -31,6 +31,9 @@
 static void set_live_bg (Display *display, Window xwindow, int mode);
 void quit_from_program (Animation_WallpaperPrivate *priv);
 void view_state_changed (Animation_WallpaperPrivate *priv);
+static gboolean short_timeout (AWallpaperPlugin *desktop_plugin);
+void run_long_timeout(AWallpaperPlugin *desktop_plugin);
+gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
 
 static 
 void set_live_bg (Display *display, Window xwindow, int mode)
@@ -52,12 +55,7 @@ void
 view_state_changed (Animation_WallpaperPrivate *priv)
 {
    fprintf(stderr," VIew %i State %i\n", priv->view, priv->visible);
-   if (priv->visible){
-       if (!priv->running){
-            if (!strcmp(priv->theme, "Xsnow")){
-                init_scene_Xsnow(priv->desktop_plugin);
-            }
-       }
+   if (priv->visible){       
        if (!strcmp(priv->theme,"Video")){
            if (priv->pipeline){
                gst_element_set_state (priv->pipeline, GST_STATE_PLAYING);
@@ -65,6 +63,11 @@ view_state_changed (Animation_WallpaperPrivate *priv)
                init_scene_Video(priv->desktop_plugin);
            }
        }
+       if (!priv->running){
+            if (g_hash_table_lookup(priv->hash_theme, "exec_path")){
+                init_scene_External(priv->desktop_plugin);
+            }
+       }
        if (priv->long_timer == 0 ){
             priv->long_timer = g_timeout_add(LONG_TIMER, (GtkFunction)long_timeout, priv->desktop_plugin);
             run_long_timeout(priv->desktop_plugin);
@@ -131,7 +134,7 @@ quit_from_program (Animation_WallpaperPrivate *priv)
 	     }
 	     destroy_scene(priv->desktop_plugin);
          osso_deinitialize(priv->osso);
-         g_hash_table_destroy(priv->hash_scene_func);
+         //g_hash_table_destroy(priv->hash_scene_func);
          g_free(priv->desktop_plugin);
          priv->desktop_plugin = NULL;
          g_free(priv);
@@ -140,6 +143,127 @@ quit_from_program (Animation_WallpaperPrivate *priv)
      fprintf(stderr,"end of quit_from_program\n");
      gtk_main_quit();;
 }
+/*******************************************************************************/
+static gboolean
+short_timeout (AWallpaperPlugin *desktop_plugin)
+{
+    //gint daytime = get_daytime();
+    GSList * tmp;
+    void (*pfunc)(gpointer, gpointer);
+    time_t now;
+    Actor *actor;
+    gboolean stop_flag = TRUE;
+
+    if (!desktop_plugin->priv->visible || !desktop_plugin->priv->rich_animation){
+        desktop_plugin->priv->short_timer = 0;
+        return FALSE;
+    }
+
+    now = time(NULL);
+    //scene.daytime = daytime;
+    /* fprintf(stderr, "Short timer %d\n", now); */
+    tmp = desktop_plugin->priv->scene->actors;
+    while (tmp != NULL){
+           actor = tmp->data;
+           if (now >= actor->time_start_animation  
+               && actor->time_start_animation > 0
+               /* && now - actor->time_start_animation <= actor->duration_animation*/){
+                pfunc = actor->func_change;
+                if (pfunc){ 
+                    (*pfunc)(actor, desktop_plugin);
+                    stop_flag = FALSE;
+                }
+            }
+            tmp = g_slist_next(tmp);
+    }
+    if (stop_flag){
+         desktop_plugin->priv->short_timer = 0;
+         return FALSE;
+    }else
+         return TRUE; /* keep running this event */
+}
+
+void
+run_long_timeout(AWallpaperPlugin *desktop_plugin)
+{
+
+    gint daytime = get_daytime();
+    GSList * tmp;
+    void (*pfunc)(gpointer, gpointer);
+    time_t now;
+    Actor *actor;
+
+    if (!desktop_plugin->priv->scene)
+	return;
+    /*ifprintf(stderr, "!!!run long timeout short_timer=%d\n", desktop_plugin->priv->short_timer); */
+    if (desktop_plugin->priv->scene->daytime != daytime){
+        desktop_plugin->priv->scene->daytime = daytime;
+        tmp = desktop_plugin->priv->scene->actors;
+        while (tmp != NULL){
+            //change_actor(tmp->data);
+            pfunc =((Actor*)tmp->data)->func_change;
+            if (pfunc){
+                (*pfunc)(tmp->data, desktop_plugin);
+            }
+            tmp = g_slist_next(tmp);
+        }
+    }
+   
+    now = time(NULL);
+    //fprintf(stderr, "Now  %d\n", now);
+    tmp = desktop_plugin->priv->scene->actors;
+    while (tmp != NULL){
+        actor = tmp->data;
+        if (now >= actor->time_start_animation  
+            && actor->time_start_animation > 0
+            && desktop_plugin->priv->short_timer == 0){
+            /* fprintf(stderr, "start short timer act = %s %d\n", actor->name, now); */
+            if (desktop_plugin->priv->rich_animation){
+                actor->time_start_animation = now;
+                desktop_plugin->priv->short_timer = g_timeout_add(SHORT_TIMER, (GtkFunction)short_timeout, desktop_plugin);
+            }
+            else {
+                (*actor->func_change)(actor, desktop_plugin);
+            }
+        }
+        tmp = g_slist_next(tmp);
+    }
+ 
+}
+
+gboolean
+long_timeout (AWallpaperPlugin *desktop_plugin)
+{
+    GstFormat fmt = GST_FORMAT_TIME;
+    gint64 p;
+
+    /*fprintf(stderr, "long_timeout %i\n", desktop_plugin->priv->long_timer); */
+    if (desktop_plugin->priv->pipeline){
+	if (!desktop_plugin->priv->visible){
+		gst_element_query_position(desktop_plugin->priv->pipeline, &fmt, &p);
+		desktop_plugin->priv->theme_int_parametr1 = p / GST_SECOND;
+		gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_NULL);
+		gst_object_unref (GST_OBJECT (desktop_plugin->priv->pipeline));
+		desktop_plugin->priv->pipeline = NULL;
+	}
+	return TRUE;  
+    }
+
+    if (desktop_plugin->priv->long_timer == 0 )
+        return FALSE;
+    if (!desktop_plugin->priv->visible){
+        if(desktop_plugin->priv->short_timer != 0){
+            g_source_remove(desktop_plugin->priv->short_timer);
+            desktop_plugin->priv->short_timer = 0;
+        }
+        desktop_plugin->priv->long_timer = 0;
+        return FALSE;
+    }
+
+    run_long_timeout(desktop_plugin);
+    return TRUE; /* keep running this event */
+}
+
 /*******************************************************************************/
 int
 main(int argc, char *argv[])
@@ -184,14 +308,6 @@ main(int argc, char *argv[])
     
     gtk_widget_show_all(GTK_WIDGET(main_widget));
 
-    priv->hash_scene_func = g_hash_table_new(g_str_hash, g_str_equal);
-    g_hash_table_insert(priv->hash_scene_func, g_strdup("Accel"),  (gpointer)&init_scene_Accel);
-    g_hash_table_insert(priv->hash_scene_func, g_strdup("Berlin"), (gpointer)&init_scene_Berlin);
-    g_hash_table_insert(priv->hash_scene_func, g_strdup("Modern"), (gpointer)&init_scene_Modern);
-    g_hash_table_insert(priv->hash_scene_func, g_strdup("Matrix"), (gpointer)&init_scene_Matrix);
-    g_hash_table_insert(priv->hash_scene_func, g_strdup("Video"),  (gpointer)&init_scene_Video);
-    g_hash_table_insert(priv->hash_scene_func, g_strdup("Xsnow"),  (gpointer)&init_scene_Xsnow);
-
     priv->scene = NULL;
     priv->pipeline = NULL;
     priv->podpid = -1;
@@ -206,9 +322,8 @@ main(int argc, char *argv[])
     else 
         priv->visible = FALSE;
 
-    /* Load config */
-    read_config(priv);
-
+    fill_priv(priv);
+    
     /* Initialize DBUS */
     livewp_initialize_dbus(priv);
     set_live_bg(GDK_WINDOW_XDISPLAY (main_widget->window), GDK_WINDOW_XID (main_widget->window), view);
