@@ -34,7 +34,7 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper Version 0.8.2 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper Version 0.8.1 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
 Copyright(c) 2010 for design themes Berlin, Modern and Accel Vasya Bobrikov\n \
 Copyright(c) 2010 for design theme Matrix and icons Andrew Zhilin\n \
@@ -539,7 +539,6 @@ void
 additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate *priv){
 
     GtkWidget *file_button;
-    GtkWidget *sound_button;
     GtkWidget *rich_animation_button;
 
     if (priv->theme_string_parametr1)
@@ -560,13 +559,16 @@ additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate
                                    rich_animation_button, TRUE, TRUE, 5);
     g_object_set_data(G_OBJECT(priv->window), "rich_animation_button", rich_animation_button);
     /* Create sound button */  
+#if 0
+
+    /* Doesn't work in real device. Hardware volume buttons can to change volume for mutted track */
     sound_button = create_bool_button(priv->theme_bool_parametr1, _("Sound"));
     gtk_box_pack_start(GTK_BOX(vbox),
                                    sound_button, TRUE, TRUE, 5);
     g_object_set_data(G_OBJECT(priv->window), "sound_button", sound_button);
-
-    gtk_widget_show (file_button);
     gtk_widget_show (sound_button);
+#endif
+    gtk_widget_show (file_button);
     gtk_widget_show (rich_animation_button);
 
 }
@@ -684,14 +686,15 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                             g_free(priv->theme_string_parametr1);
                         priv->theme_string_parametr1 = g_strdup((gchar*)hildon_button_get_value (HILDON_BUTTON(button1)));
                     }
+                    /* 
                     temp_button = g_object_get_data(G_OBJECT(priv->window), "sound_button");
                     if (temp_button){
-                        /* Check rich animation */
                         if (hildon_check_button_get_active (HILDON_CHECK_BUTTON(temp_button)))
                             priv->theme_bool_parametr1 = TRUE;
                         else
                             priv->theme_bool_parametr1 = FALSE;
                     }
+                    */
                 }
                 /* Check external themes */
                 GSList *store = priv->extheme_list;
